@@ -24,7 +24,7 @@ logger = logging.getLogger(__name__)
 try:
     from numba import njit  # pylint: disable=import-error
 except (ImportError, ModuleNotFoundError):
-    logger.info("Numba not found, replacing njit() with no-op implementation. " "Enable it with 'pip install numba'.")
+    logger.info("Numba not found, replacing njit() with no-op implementation. Enable it with 'pip install numba'.")
 
     def njit(f):
         return f
@@ -47,6 +47,7 @@ class BaseKnowledgeGraph(BaseComponent):
         output = {"sparql_result": result}
         return output, "output_1"
 
+    @abstractmethod
     def query(self, sparql_query: str, index: Optional[str] = None, headers: Optional[Dict[str, str]] = None):
         raise NotImplementedError
 
@@ -341,9 +342,7 @@ class BaseDocumentStore(BaseComponent):
     ) -> int:
         pass
 
-    @staticmethod
-    @njit  # (fastmath=True)
-    def normalize_embedding(emb: np.ndarray) -> None:
+    def normalize_embedding(self, emb: np.ndarray) -> None:
         """
         Performs L2 normalization of embeddings vector inplace. Input can be a single vector (1D array) or a matrix
         (2D array).
@@ -352,16 +351,26 @@ class BaseDocumentStore(BaseComponent):
 
         # Single vec
         if len(emb.shape) == 1:
-            norm = np.sqrt(emb.dot(emb))  # faster than np.linalg.norm()
-            if norm != 0.0:
-                emb /= norm
+            self._normalize_embedding_1D(emb)
         # 2D matrix
         else:
-            for vec in emb:
-                vec = np.ascontiguousarray(vec)
-                norm = np.sqrt(vec.dot(vec))
-                if norm != 0.0:
-                    vec /= norm
+            self._normalize_embedding_2D(emb)
+
+    @staticmethod
+    @njit  # (fastmath=True)
+    def _normalize_embedding_1D(emb: np.ndarray) -> None:
+        norm = np.sqrt(emb.dot(emb))  # faster than np.linalg.norm()
+        if norm != 0.0:
+            emb /= norm
+
+    @staticmethod
+    @njit  # (fastmath=True)
+    def _normalize_embedding_2D(emb: np.ndarray) -> None:
+        for vec in emb:
+            vec = np.ascontiguousarray(vec)
+            norm = np.sqrt(vec.dot(vec))
+            if norm != 0.0:
+                vec /= norm
 
     def finalize_raw_score(self, raw_score: float, similarity: Optional[str]) -> float:
         if similarity == "cosine":
@@ -512,6 +521,16 @@ class BaseDocumentStore(BaseComponent):
     ):
         pass
 
+    @abstractmethod
+    def delete_index(self, index: str):
+        """
+        Delete an existing index. The index including all data will be removed.
+
+        :param index: The name of the index to delete.
+        :return: None
+        """
+        pass
+
     @abstractmethod
     def _create_document_field_map(self) -> Dict:
         pass
