@@ -1,15 +1,15 @@
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Union, List, Optional, Dict, Generator
 
 if TYPE_CHECKING:
     from haystack.nodes.retriever import BaseRetriever
 
 import json
 import logging
-from pathlib import Path
-from typing import Union, List, Optional, Dict, Generator
-from tqdm.auto import tqdm
 import warnings
 import numpy as np
+from copy import deepcopy
+from pathlib import Path
+from tqdm.auto import tqdm
 from inspect import Signature, signature
 
 try:
@@ -22,7 +22,6 @@ except (ImportError, ModuleNotFoundError) as ie:
 
     _optional_component_not_installed(__name__, "faiss", ie)
 
-
 from haystack.schema import Document
 from haystack.document_stores.base import get_batches_from_generator
 
@@ -47,7 +46,7 @@ class FAISSDocumentStore(SQLDocumentStore):
         vector_dim: int = None,
         embedding_dim: int = 768,
         faiss_index_factory_str: str = "Flat",
-        faiss_index: "Optional[faiss.swigfaiss.Index]" = None,
+        faiss_index: Optional[faiss.swigfaiss.Index] = None,
         return_embedding: bool = False,
         index: str = "document",
         similarity: str = "dot_product",
@@ -112,21 +111,6 @@ class FAISSDocumentStore(SQLDocumentStore):
             self.__class__.__init__(self, **init_params)  # pylint: disable=non-parent-init-called
             return
 
-        # save init parameters to enable export of component config as YAML
-        self.set_config(
-            sql_url=sql_url,
-            vector_dim=vector_dim,
-            embedding_dim=embedding_dim,
-            faiss_index_factory_str=faiss_index_factory_str,
-            return_embedding=return_embedding,
-            duplicate_documents=duplicate_documents,
-            index=index,
-            similarity=similarity,
-            embedding_field=embedding_field,
-            progress_bar=progress_bar,
-            isolation_level=isolation_level,
-        )
-
         if similarity in ("dot_product", "cosine"):
             self.similarity = similarity
             self.metric_type = faiss.METRIC_INNER_PRODUCT
@@ -299,9 +283,7 @@ class FAISSDocumentStore(SQLDocumentStore):
             progress_bar.close()
 
     def _create_document_field_map(self) -> Dict:
-        return {
-            self.index: self.embedding_field,
-        }
+        return {self.index: self.embedding_field}
 
     def update_embeddings(
         self,
@@ -543,6 +525,21 @@ class FAISSDocumentStore(SQLDocumentStore):
 
         super().delete_documents(index=index, ids=ids, filters=filters)
 
+    def delete_index(self, index: str):
+        """
+        Delete an existing index. The index including all data will be removed.
+
+        :param index: The name of the index to delete.
+        :return: None
+        """
+        if index == self.index:
+            logger.warning(
+                f"Deletion of default index '{index}' detected. "
+                f"If you plan to use this index again, please reinstantiate '{self.__class__.__name__}' in order to avoid side-effects."
+            )
+        del self.faiss_indexes[index]
+        super().delete_index(index)
+
     def query_by_embedding(
         self,
         query_emb: np.ndarray,
@@ -616,8 +613,15 @@ class FAISSDocumentStore(SQLDocumentStore):
             config_path = index_path.with_suffix(".json")
 
         faiss.write_index(self.faiss_indexes[self.index], str(index_path))
+
+        config_to_save = deepcopy(self._component_config["params"])
+        keys_to_remove = ["faiss_index", "faiss_index_path"]
+        for key in keys_to_remove:
+            if key in config_to_save.keys():
+                del config_to_save[key]
+
         with open(config_path, "w") as ipp:
-            json.dump(self.pipeline_config["params"], ipp)
+            json.dump(config_to_save, ipp, default=str)
 
     def _load_init_params_from_config(
         self, index_path: Union[str, Path], config_path: Optional[Union[str, Path]] = None
