@@ -134,15 +134,8 @@ class SQLDocumentStore(BaseDocumentStore):
         :param check_same_thread: Set to False to mitigate multithreading issues in older SQLite versions (see https://docs.sqlalchemy.org/en/14/dialects/sqlite.html?highlight=check_same_thread#threading-pooling-behavior)
         :param isolation_level: see SQLAlchemy's `isolation_level` parameter for `create_engine()` (https://docs.sqlalchemy.org/en/14/core/engines.html#sqlalchemy.create_engine.params.isolation_level)
         """
+        super().__init__()
 
-        # save init parameters to enable export of component config as YAML
-        self.set_config(
-            url=url,
-            index=index,
-            label_index=label_index,
-            duplicate_documents=duplicate_documents,
-            check_same_thread=check_same_thread,
-        )
         create_engine_params = {}
         if isolation_level:
             create_engine_params["isolation_level"] = isolation_level
@@ -257,11 +250,7 @@ class SQLDocumentStore(BaseDocumentStore):
 
         if return_embedding is True:
             raise Exception("return_embeddings is not supported by SQLDocumentStore.")
-        result = self._query(
-            index=index,
-            filters=filters,
-            batch_size=batch_size,
-        )
+        result = self._query(index=index, filters=filters, batch_size=batch_size)
         yield from result
 
     def _create_document_field_map(self) -> Dict:
@@ -373,7 +362,8 @@ class SQLDocumentStore(BaseDocumentStore):
         :param duplicate_documents: Handle duplicates document based on parameter options.
                                     Parameter options : ( 'skip','overwrite','fail')
                                     skip: Ignore the duplicates documents
-                                    overwrite: Update any existing documents with the same ID when adding documents.
+                                    overwrite: Update any existing documents with the same ID when adding documents
+                                    but is considerably slower (default).
                                     fail: an error is raised if the document ID of the document being added already
                                     exists.
 
@@ -396,24 +386,30 @@ class SQLDocumentStore(BaseDocumentStore):
             documents=document_objects, index=index, duplicate_documents=duplicate_documents
         )
         for i in range(0, len(document_objects), batch_size):
+            docs_orm = []
             for doc in document_objects[i : i + batch_size]:
                 meta_fields = doc.meta or {}
                 vector_id = meta_fields.pop("vector_id", None)
                 meta_orms = [MetaDocumentORM(name=key, value=value) for key, value in meta_fields.items()]
-                doc_orm = DocumentORM(
-                    id=doc.id,
-                    content=doc.to_dict()["content"],
-                    content_type=doc.content_type,
-                    vector_id=vector_id,
-                    meta=meta_orms,
-                    index=index,
-                )
+                doc_mapping = {
+                    "id": doc.id,
+                    "content": doc.to_dict()["content"],
+                    "content_type": doc.content_type,
+                    "vector_id": vector_id,
+                    "meta": meta_orms,
+                    "index": index,
+                }
                 if duplicate_documents == "overwrite":
+                    doc_orm = DocumentORM(**doc_mapping)
                     # First old meta data cleaning is required
                     self.session.query(MetaDocumentORM).filter_by(document_id=doc.id).delete()
                     self.session.merge(doc_orm)
                 else:
-                    self.session.add(doc_orm)
+                    docs_orm.append(doc_mapping)
+
+            if docs_orm:
+                self.session.bulk_insert_mappings(DocumentORM, docs_orm)
+
             try:
                 self.session.commit()
             except Exception as ex:
@@ -482,13 +478,7 @@ class SQLDocumentStore(BaseDocumentStore):
         index = index or self.index
         for chunk_map in self.chunked_dict(vector_id_map, size=batch_size):
             self.session.query(DocumentORM).filter(DocumentORM.id.in_(chunk_map), DocumentORM.index == index).update(
-                {
-                    DocumentORM.vector_id: case(
-                        chunk_map,
-                        value=DocumentORM.id,
-                    )
-                },
-                synchronize_session=False,
+                {DocumentORM.vector_id: case(chunk_map, value=DocumentORM.id)}, synchronize_session=False
             )
             try:
                 self.session.commit()
@@ -538,8 +528,7 @@ class SQLDocumentStore(BaseDocumentStore):
         if filters:
             for key, values in filters.items():
                 query = query.join(MetaDocumentORM, aliased=True).filter(
-                    MetaDocumentORM.name == key,
-                    MetaDocumentORM.value.in_(values),
+                    MetaDocumentORM.name == key, MetaDocumentORM.value.in_(values)
                 )
 
         if only_documents_without_embedding:
@@ -658,8 +647,7 @@ class SQLDocumentStore(BaseDocumentStore):
             if filters:
                 for key, values in filters.items():
                     document_ids_to_delete = document_ids_to_delete.join(MetaDocumentORM, aliased=True).filter(
-                        MetaDocumentORM.name == key,
-                        MetaDocumentORM.value.in_(values),
+                        MetaDocumentORM.name == key, MetaDocumentORM.value.in_(values)
                     )
             if ids:
                 document_ids_to_delete = document_ids_to_delete.filter(DocumentORM.id.in_(ids))
@@ -670,6 +658,15 @@ class SQLDocumentStore(BaseDocumentStore):
 
         self.session.commit()
 
+    def delete_index(self, index: str):
+        """
+        Delete an existing index. The index including all data will be removed.
+
+        :param index: The name of the index to delete.
+        :return: None
+        """
+        self.delete_documents(index)
+
     def delete_labels(
         self,
         index: Optional[str] = None,
