@@ -62,11 +62,7 @@ def f1_macro(preds, labels):
 def pearson_and_spearman(preds, labels):
     pearson_corr = pearsonr(preds, labels)[0]
     spearman_corr = spearmanr(preds, labels)[0]
-    return {
-        "pearson": pearson_corr,
-        "spearman": spearman_corr,
-        "corr": (pearson_corr + spearman_corr) / 2,
-    }
+    return {"pearson": pearson_corr, "spearman": spearman_corr, "corr": (pearson_corr + spearman_corr) / 2}
 
 
 def compute_metrics(metric: str, preds, labels):
