@@ -39,8 +39,7 @@ class JoinDocuments(BaseComponent):
             weights is not None and join_mode == "concatenate"
         ), "Weights are not compatible with 'concatenate' join_mode."
 
-        # save init parameters to enable export of component config as YAML
-        self.set_config(join_mode=join_mode, weights=weights, top_k_join=top_k_join)
+        super().__init__()
 
         self.join_mode = join_mode
         self.weights = [float(i) / sum(weights) for i in weights] if weights else None
