@@ -1,17 +1,20 @@
 from typing import List, Dict, Any, Optional, Union
 
+from abc import abstractmethod
 from haystack.nodes.base import BaseComponent
 
 
 class BasePreProcessor(BaseComponent):
     outgoing_edges = 1
 
+    @abstractmethod
     def process(
         self,
         documents: Union[dict, List[dict]],
         clean_whitespace: Optional[bool] = True,
         clean_header_footer: Optional[bool] = False,
         clean_empty_lines: Optional[bool] = True,
+        remove_substrings: List[str] = [],
         split_by: Optional[str] = "word",
         split_length: Optional[int] = 1000,
         split_overlap: Optional[int] = None,
@@ -22,15 +25,18 @@ class BasePreProcessor(BaseComponent):
         """
         raise NotImplementedError
 
+    @abstractmethod
     def clean(
         self,
         document: dict,
         clean_whitespace: bool,
         clean_header_footer: bool,
         clean_empty_lines: bool,
+        remove_substrings: List[str],
     ) -> Dict[str, Any]:
         raise NotImplementedError
 
+    @abstractmethod
     def split(
         self,
         document: dict,
