@@ -43,6 +43,7 @@ class PreProcessor(BasePreProcessor):
         clean_whitespace: bool = True,
         clean_header_footer: bool = False,
         clean_empty_lines: bool = True,
+        remove_substrings: List[str] = [],
         split_by: str = "word",
         split_length: int = 200,
         split_overlap: int = 0,
@@ -56,6 +57,7 @@ class PreProcessor(BasePreProcessor):
                                      or similar.
         :param clean_whitespace: Strip whitespaces before or after each line in the text.
         :param clean_empty_lines: Remove more than two empty lines in the text.
+        :param remove_substrings: Remove specified substrings from the text.
         :param split_by: Unit for splitting the document. Can be "word", "sentence", or "passage". Set to None to disable splitting.
         :param split_length: Max. number of the above split unit (e.g. words) that are allowed in one document. For instance, if n -> 10 & split_by ->
                            "sentence", then each output document will have 10 sentences.
@@ -70,17 +72,7 @@ class PreProcessor(BasePreProcessor):
                                                 the number of words will be <= split_length.
         :param language: The language used by "nltk.tokenize.sent_tokenize" in iso639 format. Available options: "en", "es", "de", "fr" & many more.
         """
-
-        # save init parameters to enable export of component config as YAML
-        self.set_config(
-            clean_whitespace=clean_whitespace,
-            clean_header_footer=clean_header_footer,
-            clean_empty_lines=clean_empty_lines,
-            split_by=split_by,
-            split_length=split_length,
-            split_overlap=split_overlap,
-            split_respect_sentence_boundary=split_respect_sentence_boundary,
-        )
+        super().__init__()
 
         try:
             nltk.data.find("tokenizers/punkt")
@@ -90,6 +82,7 @@ class PreProcessor(BasePreProcessor):
         self.clean_whitespace = clean_whitespace
         self.clean_header_footer = clean_header_footer
         self.clean_empty_lines = clean_empty_lines
+        self.remove_substrings = remove_substrings
         self.split_by = split_by
         self.split_length = split_length
         self.split_overlap = split_overlap
@@ -103,6 +96,7 @@ class PreProcessor(BasePreProcessor):
         clean_whitespace: Optional[bool] = None,
         clean_header_footer: Optional[bool] = None,
         clean_empty_lines: Optional[bool] = None,
+        remove_substrings: List[str] = [],
         split_by: Optional[str] = None,
         split_length: Optional[int] = None,
         split_overlap: Optional[int] = None,
@@ -117,6 +111,7 @@ class PreProcessor(BasePreProcessor):
             "clean_whitespace": clean_whitespace,
             "clean_header_footer": clean_header_footer,
             "clean_empty_lines": clean_empty_lines,
+            "remove_substrings": remove_substrings,
             "split_by": split_by,
             "split_length": split_length,
             "split_overlap": split_overlap,
@@ -125,9 +120,9 @@ class PreProcessor(BasePreProcessor):
 
         ret = []
 
-        if type(documents) == dict:
+        if isinstance(documents, dict):
             ret = self._process_single(document=documents, **kwargs)  # type: ignore
-        elif type(documents) == list:
+        elif isinstance(documents, list):
             ret = self._process_batch(documents=list(documents), **kwargs)
 
         else:
@@ -141,6 +136,7 @@ class PreProcessor(BasePreProcessor):
         clean_whitespace: Optional[bool] = None,
         clean_header_footer: Optional[bool] = None,
         clean_empty_lines: Optional[bool] = None,
+        remove_substrings: List[str] = [],
         split_by: Optional[str] = None,
         split_length: Optional[int] = None,
         split_overlap: Optional[int] = None,
@@ -153,6 +149,8 @@ class PreProcessor(BasePreProcessor):
             clean_header_footer = self.clean_header_footer
         if clean_empty_lines is None:
             clean_empty_lines = self.clean_empty_lines
+        if not remove_substrings:
+            remove_substrings = self.remove_substrings
         if split_by is None:
             split_by = self.split_by
         if split_length is None:
@@ -167,6 +165,7 @@ class PreProcessor(BasePreProcessor):
             clean_whitespace=clean_whitespace,
             clean_header_footer=clean_header_footer,
             clean_empty_lines=clean_empty_lines,
+            remove_substrings=remove_substrings,
         )
         split_documents = self.split(
             document=cleaned_document,
@@ -187,6 +186,7 @@ class PreProcessor(BasePreProcessor):
         clean_whitespace: bool,
         clean_header_footer: bool,
         clean_empty_lines: bool,
+        remove_substrings: List[str],
     ) -> dict:
         """
         Perform document cleaning on a single document and return a single document. This method will deal with whitespaces, headers, footers
@@ -210,7 +210,13 @@ class PreProcessor(BasePreProcessor):
         if clean_empty_lines:
             text = re.sub(r"\n\n+", "\n\n", text)
 
-        document["content"] = text
+        for substring in remove_substrings:
+            text = text.replace(substring, "")
+
+        if text != document["content"]:
+            document = deepcopy(document)
+            document["content"] = text
+
         return document
 
     def split(
