@@ -95,17 +95,7 @@ class TableReader(BaseReader):
                             query + table exceed max_seq_len, the table will be truncated by removing rows until the
                             input size fits the model.
         """
-        # Save init parameters to enable export of component config as YAML
-        self.set_config(
-            model_name_or_path=model_name_or_path,
-            model_version=model_version,
-            tokenizer=tokenizer,
-            use_gpu=use_gpu,
-            top_k=top_k,
-            top_k_per_candidate=top_k_per_candidate,
-            return_no_answer=return_no_answer,
-            max_seq_len=max_seq_len,
-        )
+        super().__init__()
 
         self.devices, _ = initialize_device_settings(use_cuda=use_gpu, multi_gpu=False)
         config = TapasConfig.from_pretrained(model_name_or_path)
@@ -480,18 +470,7 @@ class RCIReader(BaseReader):
                             query + table exceed max_seq_len, the table will be truncated by removing rows until the
                             input size fits the model.
         """
-        # Save init parameters to enable export of component config as YAML
-        self.set_config(
-            row_model_name_or_path=row_model_name_or_path,
-            column_model_name_or_path=column_model_name_or_path,
-            row_model_version=row_model_version,
-            column_model_version=column_model_version,
-            row_tokenizer=row_tokenizer,
-            column_tokenizer=column_tokenizer,
-            use_gpu=use_gpu,
-            top_k=top_k,
-            max_seq_len=max_seq_len,
-        )
+        super().__init__()
 
         self.devices, _ = initialize_device_settings(use_cuda=use_gpu, multi_gpu=False)
         self.row_model = AutoModelForSequenceClassification.from_pretrained(
