@@ -60,19 +60,7 @@ class TransformersReader(BaseReader):
         :param max_seq_len: max sequence length of one input text for the model
         :param doc_stride: length of striding window for splitting long texts (used if len(text) > max_seq_len)
         """
-        # save init parameters to enable export of component config as YAML
-        self.set_config(
-            model_name_or_path=model_name_or_path,
-            model_version=model_version,
-            tokenizer=tokenizer,
-            context_window_size=context_window_size,
-            use_gpu=use_gpu,
-            top_k=top_k,
-            doc_stride=doc_stride,
-            top_k_per_candidate=top_k_per_candidate,
-            return_no_answers=return_no_answers,
-            max_seq_len=max_seq_len,
-        )
+        super().__init__()
 
         self.devices, _ = initialize_device_settings(use_cuda=use_gpu, multi_gpu=False)
         device = 0 if self.devices[0].type == "cuda" else -1
