@@ -7,7 +7,7 @@ import requests
 import logging
 import importlib
 from pathlib import Path
-
+from haystack.telemetry import send_tutorial_event
 
 logger = logging.getLogger(__name__)
 
@@ -50,7 +50,7 @@ def _optional_component_not_installed(component: str, dep_group: str, source_err
     raise ImportError(
         f"Failed to import '{component}', "
         "which is an optional component in Haystack.\n"
-        f"Run 'pip install farm-haystack[{dep_group}]' "
+        f"Run 'pip install 'farm-haystack[{dep_group}]'' "
         "to install the required dependencies and make this component available."
     ) from source_error
 
@@ -69,6 +69,9 @@ def fetch_archive_from_http(url: str, output_dir: str, proxies: Optional[dict] =
     if not path.exists():
         path.mkdir(parents=True)
 
+    if "deepset.ai-farm-qa/datasets" in url or "dl.fbaipublicfiles.com" in url or "fandom-qa.s3" in url:
+        send_tutorial_event(url=url)
+
     is_not_empty = len(list(Path(path).rglob("*"))) > 0
     if is_not_empty:
         logger.info(f"Found data stored in `{output_dir}`. Delete this first if you really want to fetch new data.")
