@@ -11,6 +11,13 @@ from fastapi import APIRouter, UploadFile, File, Form, HTTPException, Depends
 from pydantic import BaseModel
 
 from haystack.pipelines.base import Pipeline
+from haystack.errors import PipelineConfigError
+from haystack.pipelines.config import (
+    get_component_definitions,
+    get_pipeline_definition,
+    read_pipeline_config_from_yaml,
+    validate_config,
+)
 from rest_api.config import PIPELINE_YAML_PATH, FILE_UPLOAD_PATH, INDEXING_PIPELINE_NAME
 from rest_api.controller.utils import as_form
 
@@ -19,11 +26,10 @@ logger = logging.getLogger(__name__)
 router = APIRouter()
 
 try:
-    pipeline_config = Pipeline._read_pipeline_config_from_yaml(Path(PIPELINE_YAML_PATH))
-    pipeline_definition = Pipeline._get_pipeline_definition(
-        pipeline_config=pipeline_config, pipeline_name=INDEXING_PIPELINE_NAME
-    )
-    definitions = Pipeline._get_component_definitions(
+    pipeline_config = read_pipeline_config_from_yaml(Path(PIPELINE_YAML_PATH))
+    validate_config(pipeline_config)
+    pipeline_definition = get_pipeline_definition(pipeline_config=pipeline_config, pipeline_name=INDEXING_PIPELINE_NAME)
+    component_definitions = get_component_definitions(
         pipeline_config=pipeline_config, overwrite_with_env_variables=True
     )
     # Since each instance of FAISSDocumentStore creates an in-memory FAISS index, the Indexing & Query Pipelines would
@@ -32,8 +38,8 @@ try:
     is_faiss_or_inmemory_present = False
     for node in pipeline_definition["nodes"]:
         if (
-            definitions[node["name"]]["type"] == "FAISSDocumentStore"
-            or definitions[node["name"]]["type"] == "InMemoryDocumentStore"
+            component_definitions[node["name"]]["type"] == "FAISSDocumentStore"
+            or component_definitions[node["name"]]["type"] == "InMemoryDocumentStore"
         ):
             is_faiss_or_inmemory_present = True
             break
@@ -44,10 +50,10 @@ try:
         INDEXING_PIPELINE = None
     else:
         INDEXING_PIPELINE = Pipeline.load_from_yaml(Path(PIPELINE_YAML_PATH), pipeline_name=INDEXING_PIPELINE_NAME)
-except KeyError:
-    INDEXING_PIPELINE = None
-    logger.warning("Indexing Pipeline not found in the YAML configuration. File Upload API will not be available.")
 
+except PipelineConfigError as e:
+    INDEXING_PIPELINE = None
+    logger.error(f"{e.message}. File Upload API will not be available.")
 
 # create directory for uploading files
 os.makedirs(FILE_UPLOAD_PATH, exist_ok=True)
