@@ -1,9 +1,10 @@
 from pathlib import Path
 
+from haystack import Document
 from haystack.nodes.file_converter.pdf import PDFToTextConverter
 from haystack.nodes.preprocessor.preprocessor import PreProcessor
 
-from conftest import SAMPLES_PATH
+from .conftest import SAMPLES_PATH
 
 TEXT = """
 This is a sample sentence in paragraph_1. This is a sample sentence in paragraph_1. This is a sample sentence in 
@@ -27,10 +28,7 @@ def test_preprocess_sentence_split():
     assert len(documents) == 15
 
     preprocessor = PreProcessor(
-        split_length=10,
-        split_overlap=0,
-        split_by="sentence",
-        split_respect_sentence_boundary=False,
+        split_length=10, split_overlap=0, split_by="sentence", split_respect_sentence_boundary=False
     )
     documents = preprocessor.process(document)
     assert len(documents) == 2
@@ -91,3 +89,23 @@ def test_clean_header_footer():
 
     assert "This is a header." not in documents[0]["content"]
     assert "footer" not in documents[0]["content"]
+
+
+def test_remove_substrings():
+    document = {"content": "This is a header. Some additional text. wiki. Some emoji ✨ 🪲 Weird whitespace\b\b\b."}
+
+    # check that the file contains the substrings we are about to remove
+    assert "This is a header." in document["content"]
+    assert "wiki" in document["content"]
+    assert "🪲" in document["content"]
+    assert "whitespace" in document["content"]
+    assert "✨" in document["content"]
+
+    preprocessor = PreProcessor(remove_substrings=["This is a header.", "wiki", "🪲"])
+    documents = preprocessor.process(document)
+
+    assert "This is a header." not in documents[0]["content"]
+    assert "wiki" not in documents[0]["content"]
+    assert "🪲" not in documents[0]["content"]
+    assert "whitespace" in documents[0]["content"]
+    assert "✨" in documents[0]["content"]
